;
; Add extensions to NetLogo
;
extensions [ gis ]
;
; Define types of agents
;
breed [towns town] ; where people go when they migrate
breed [villages village] ; class to store village specific stuff
breed [households house] ; main class of households
breed [storage oneStore] ; class for water storage.  Storage has types
breed [taps tap] ; class for drinking water sources.  Tap has houses attached
breed [tanks tank] ; tank class, locate, capacity, state
breed [ponds pond] ; pond class, locate, capacity, state
breed [fields field] ; turtle to hold field information
breed [people person] ; individuals that make up the households
breed [powergrid power] ; location of power.  Power can mean village can have earnings in other way
;
; Define global variables
;
globals [       ; ********** variables that can be accessed anywhere **********
  readTest       ; variable to keep track of what has been read
  policyString   ; string to collect policy information
  weatherScenario
  priceScenario  ; a sequence of prices.  Scales prices in all villages.
  period         ; counter 
  discount       ; discount rate
  glo_growSC     ; growth rate of social capital, towards SC target
  villageFile    ; name of file with village information
  city           ; village object where people are who have migrated to the city.  Don't return
  marketTown     ; village object where people migrate to for a short time, and can return to provide labour
  season
  ;
  ; Storage for simulation results
  sim_totWealth
  sim_income
  sim_profit
  sim_wages
  sim_remit
  sim_subsidy
  sim_sustain
  sim_migrate
  sim_maintain
  sim_population
  sim_households
  sim_WSworking
  sim_WS
  sim_taps
  sim_SC
  sim_stored
  ;
  ; Policy related global variables
  policyBudget   ; amount of money available for policy options
  policyBudgetAcc ; accumulated expenditures
  policyTechCost ; cost of improving technology on one field
  policySCcost   ; cost of increasing social capital
  ;
  ; Defaults for things that are set by slider in the trial, and can be read from a file
  glo_memHereInit   ; number of household members in village to begin
  glo_memAwayInit   ; number of household members away and sending remittances to begin
  glo_numFldsInit   ; number of fields that household owns at beginning
  glo_wageCropShare ; share of income from crop paid to workers
  glo_wageFar       ; wage of workers that migrate away
  glo_migrateCost   ; cost of migrating from this village
  glo_remitShare    ; share of wage from migrants that is remitted
  glo_costSustain   ; subsistence cost for a village resident
  glo_hldNumInit   ; initial size of household (number of members)
  glo_irrigPrice    ; price of irrigated crop in this village
  glo_rainPrice     ; price of rainfed crop in this village
  glo_priceList     ; list of prices.  Could expand to to have a sequence of prices over time [irrigK rainK irrigR rainR]
  glo_kharifRain    ; village level average precipitation during kharif
  glo_rabiRain      ; average village level precipitation during rabi 
  glo_watHarvEffic  ; water harvesting efficiency for storage in this village
  ; [waterMinK waterMaxK yieldMaxK labNeededK priceK waterMinR waterMaxR yieldMaxR labNeededR priceR]
  glo_irrigList     ; list of information about irrigated crops
  glo_rainList      ; list of information about rainfed crops
  glo_polTechCost   ; cost of increasing technology on one field
  glo_polSCcost     ; cost of increasing social capital in one village
  glo_polDrinkCst   ; cost of adding one tap in one village
  glo_budgetTech    ; technology budget carryover
  glo_budgetRelief  ; relief budget carryover
  glo_budgetLTsto   ; long term storage budget carryover
  glo_budgetSTsto   ; sthort term storage budget carryover
  glo_budgetSC      ; social capital budget carryover
  glo_budgetRepair  ; storage repair budget carryover
  glo_budgetDrink   ; budget for installing new drinking water taps
  glo_polLTlist     ; storage for information about long term storage
  glo_polSTlist     ; storage for information about short term storage
  glo_polTaplist    ; information about taps
  glo_DEM           ; storage for Digital Elevation Model results (DEM)
  glo_DEMfile       ; storage for DEM file
  glo_pat_area      ; default area of a patch
  glo_hou_iniWealth ; initial wealth of the household at start of the simulation
]
;
; Define the variables that the different elements own
;
towns-own [
  tow_people        ; people in the town
]
villages-own [
  ;
  ; Stocks
  vil_residents     ; agent set of households in this village
  vil_socCapital    ; social capital
  vil_storeSet      ; agentset of water storage infrastructure
  vil_taps          ; taps in this village
  ;
  ; Flows
  vil_socCapSubsidy ; subsidy to build social capital in village.  Note, scale from zero to one
  vil_season        ; storage for season
  vil_rain          ; storage for this season's rainfall
  ;
  ; Variables
  vil_wageCropShare ; share of income from crop paid to workers
  vil_wageFar       ; wage of workers that migrate away
  vil_migrateCost   ; cost of migrating from this village
  vil_remitShare    ; share of wage from migrants that is remitted
  vil_costSustain   ; subsistence cost for a village resident
  vil_hldNumInit    ; initial number of members in a household
  vil_irrigPrice    ; price of irrigated crop in this village
  vil_rainPrice     ; price of rainfed crop in this village
  vil_priceList     ; list of prices.  Could expand to to have a sequence of prices over time [irrigK rainK irrigR rainR]
  vil_kharifRain    ; village level average precipitation during kharif
  vil_rabiRain      ; average village level precipitation during rabi 
  vil_growSC        ; growth rate of social capital
  ;
  ; Parameters
  vil_name          ; name of the village
  ;
  ; Village level policy variables
  vil_polSCcost     ; cost of increasing social capital
  vil_polSCstep     ; policy step when a social capital investment is made
  vil_polTaplist    ; information about a tap for this village
  vil_polLTlist     ; storage for information about LT storage
  vil_polSTlist     ; storage for information about ST storage
  vil_polTechCost
  vil_techMax
]
;
households-own [   ; ********** variables that each agent has **********
  ;
  ; Stocks
  hou_FCcash        ; financial capital that is cash
  hou_NCland        ; patch set of land owned
  hou_members       ; members of this household
  ;
  ; Flows
  hou_income        ; used to store income for the period
  hou_incProfit
  hou_incWages
  hou_incRemit
  hou_incSubsidy
  hou_incLand
  hou_cstSustain
  hou_cstMigrate
  hou_cstMaint
  ;
  ; Variables
  hou_incLocHist    ; local income history
  hou_incFarHist    ; remittance income history
  ;
  ; Parameters
  hou_vilName       ; identifier for village
  hou_ourVillage    ; turtle that is village of this household
  hou_ourTap        ; agentset of taps that this household has access to
  hou_memLocalLast  ; number of people in this household who were in the village last period
  hou_memHereInit   ; initial number of members in village
  hou_memAwayInit   ; initial number of members away from village
  hou_numFldsInit   ; initial number of  
]
;
people-own [
  ;
  ; Stocks
  peo_myHumanCap    ; the human capital I have accumulated
  ;
  ; Flows
  peo_myIncome      ; the income I have
  ;
  ; Variables
  peo_canWork       ; set equal to true if can work for someone else
  peo_inVillage     ; village where person is - if not equal to my village, then migrated
  ;
  ; Parameters
  peo_myHousehold   ; agent that is household this person belongs to
  peo_myVillage     ; village that this person belongs to
]
;
storage-own [
  ;
  ; Stocks
  sto_stored        ; amount of water stored 
  sto_working       ; set true if storage is working (not failed)
  ;
  ; Flows
  sto_used          ; water used this season
  sto_actMaintCost  ; actual maintenance cost
  sto_actCostRemain ; maintenance cost not paid
  sto_actProbFail   ; actual probability of failure
  ;
  ; Variables
  sto_probFail      ; probability storage fails
  sto_repaired      ; set true if it was repaired
  sto_repairCost    ; amount spent to repair
  ;
  ; Parameters
  sto_vilName       ; identifier for village
  sto_theVillage    ; village that this tank belongs to
  sto_storeType     ; type of storage (tank, pond)
  sto_costBuild     ; cost to build this storage 
  sto_costMaint     ; period cost of maintenance
  sto_numFields     ; number of fields that storage can connect to
  sto_toFields      ; set of fields attached to this tank
  sto_baseYield   ; water yield that occurs allways
  sto_rainYield   ; water yield that is contributed by rainfall
  sto_maxYield    ; maximum water yield from this storage in a season
]  
;
taps-own [
  ;
  ; Stocks
  ;
  ; Flows
  ;
  ; Variables
  tap_probFail      ; probability storage fails
  ;
  ; Parameters
  tap_vilName       ; identifier for village
  tap_theVillage    ; village that this tank belongs to
  tap_costBuild     ; cost to build this storage 
  tap_costMaint     ; period cost of maintenance
  tap_numHlds       ; number of households that can be attached to this tap
  tap_toHlds        ; agentset of households attached to this tap
  tap_drinkProd     ; scaling labour productivity of household members with tap
  tap_drinkSustCost ; scaling for sustainance cost when can access tap
]
;
fields-own [
  ;
  ; Stocks
  fie_tech          ; technology used on the land
  ;
  ; Flows
  fie_crop          ; crop chosen for this patch
  fie_yield         ; storage for yeild
  fie_profit        ; profit earned by this field
  fie_labUsed       ; agentset of labour used on this field
  fie_watUsed       ; amount of water used this season
  ;
  ; Variables
  ;
  ; Parameters
  fie_owner         ; turtle that owns the field
  fie_myStore       ; agentset of storage that can be accessed by this field
  fie_yieldHist     ; average yield of this field.  Five year moving average
  fie_place         ; patch where this field is located
  ; [waterMinK waterMaxK yieldMaxK labNeededK priceK waterMinR waterMaxR yieldMaxR labNeededR priceR]
  fie_irrigList     ; list of information about irrigated crops
  fie_rainList      ; list of information about rainfed crops
  fie_waterMin      ; minimum water requirements for crop grown this season
  fie_waterMax      ; maximum water requirement for crop grown this season
  fie_yieldMax      ; maximum yield for crop grown this season
  fie_labNeeded     ; labour needed for crop grown this season
  fie_price         ; price for crop grown this season
  fie_techCost      ; cost of enhancing technology by one step on this field
  fie_techMax
  fie_profitHist    ; history of field profit, used to figure out sale price
]
;
patches-own [   ; ********** variables that each patch has **********
  pat_elevation     ; elevation of this patch
  pat_rain          ; amount of rain that fell in kharif
  pat_owned         ; set to the owner of the pach if it is owned
  pat_area   ; land area of a patch
]
;******************************************************************************************************************
; INCLUDE
;******************************************************************************************************************
;
__includes [ "SL_ABM_storage_0.5.nls" "SL_ABM_fields_0.5.nls" "SL_ABM_households_0.5.nls" "SL_ABM_villages_0.5.nls" "SL_ABM_gisLoader_0.5.nls" "SL_ABM_people_0.5.nls" "SL_ABM_taps_0.5.nls" ]
;
;******************************************************************************************************************
;* SETUP                                                                                                          *
;******************************************************************************************************************
;
; Set things up
;
to setup
  clear-all
  random-seed 2147483647
  set readTest [false false false false false false false false false false false false false false]
  ;
  ; setup global variables
  setup-globals-configuration
  ;
  ; some preliminaries
  setup-preliminaries
  ;
  ; some global variables
  setup-globals
  ;
  ; Load the configuration file
  setup-load-configuration
  ;
  ; Check to see if we are running an experiment, and if we are set 
  ; the precipitation levels from the sliders.  Also, turn off the 
  ; log file, as we will just get too much stuff.
  setup-simulation
  ;
  ; setup-villages
  setup-village-plots
  ;
  reset-ticks
end
;
; Setup for a simulation.  In a simulation, we will use the precipitation
; sliders to set the precipitation level.  The idea is that this will be 
; done a large number of times.  So, don't want log files to be used
; either.  Need to collect a number of variables that can be tracked.
;
to setup-simulation
  if(runningSimulation) [
    print "Setting up simulation."
    ;
    ; Turn off log.
    set recordLog false;
    ;
    ; Set the precipitation pattern from the sliders
    set weatherScenario (sentence 
      precipScale1  precipScale2  precipScale3  precipScale4  precipScale5 
      precipScale6  precipScale7  precipScale8  precipScale9  precipScale10 
      precipScale11 precipScale12 precipScale13 precipScale14 precipScale15
      precipScale16 precipScale17 precipScale18 precipScale19 precipScale20) 
  ]
end
;
; Setup the global values.  These are read from the sliders to start, and
; used to configure the things in the village and lower level
; objects
;
to setup-globals-configuration
  ;
  ; Set all the policy sliders to zero and turn off the policy variables
  set ltStorage 0
  set stStorage 0
  set repairStorage 0
  set irrigTech 0
  set drinkingWater 0
  set SCbuilding 0
  set emergRelief 0
  set policyBudgetActive false
  set policyBudgetSpendShare 1
  ;
  ; Set some globals to values that will crash, so that we can detect missing reads
  set glo_costSustain -1
  set glo_wageCropShare -1
  set glo_wageFar -1
  set glo_migrateCost -1
  set glo_remitShare -1
  ;
  ; Default values for crop production
  ; [waterMinK waterMaxK yieldMaxK labNeededK priceK waterMinR waterMaxR yieldMaxR labNeededR priceR]
  set glo_irrigList []    ; list of information about irrigated crops
  set glo_rainList []     ; list of information about rainfed crops
  set glo_rainPrice -1
  set glo_irrigPrice -1
  set glo_priceList []  ; default list of prices for crops, different by season
  set glo_kharifRain -1
  set glo_rabiRain -1
  set glo_polTechCost -1   ; cost of increasing technology on one field
  set glo_polSCcost -1   ; cost of increasing social capital in one village
  set glo_polDrinkCst -1  ; cost of adding one tap in one village
  set glo_budgetTech 0   ; technology budget carryover
  set glo_budgetRelief 0 ; relief budget carryover
  set glo_budgetLTsto 0  ; long term storage budget carryover
  set glo_budgetSTsto 0  ; sthort term storage budget carryover
  set glo_budgetSC 0     ; social capital budget carryover
  set glo_budgetRepair 0 ; storage repair budget carryover
  set glo_growSC 0.5     ; growth rate of social capital towards target
  set glo_memHereInit -1  ; number of members here to start
  set glo_memAwayInit -1  ; number of members away to start
  set glo_hldNumInit -1  ; number of members in the household at start
  set glo_pat_area -1 ; default patch area, one area unit
  set glo_hou_iniWealth -1  ; initial wealth of the household
  ;
  ; set the default storage information
  ;   [storeType probFail costBuild costMaint numFields capacity catchSize]  
  set glo_polSTlist []
  set glo_polLTlist []
  set glo_polTaplist []
end
;
; Load the configuration file.  Want to set it up so lines that are commented, stared with a ';' or a '#' or a '%' are ignored
;
to setup-load-configuration 
  let fileName "World2.txt"
  if (not empty? configFile) [ set fileName configFile ]
  print (word "Model Configuration File: '" fileName "'")
  let logString "*\n* Configuration lines read and applied.\n*\n"
  file-open fileName
  ;
  ; The file starts each line with a work naming the agent to which the information applies.
  let line file-read-skipComments
  while [not empty? line] [
    let syntaxFlag true
    ;
    ; World configuration information
    if ((item 0 line) = "World") [
      setup-world (item 1 line)
      set readTest replace-item 0 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup information for short term storage characteristics
    if ((item 0 line) = "DEM") [
      setup-DEM-defaults (item 1 line)
      set readTest replace-item 1 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup information for the weather scenario
    if ((item 0 line) = "Weather") [
      set weatherScenario read-from-string (item 1 line)
      set readTest replace-item 2 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup the price scenario
    if ((item 0 line) = "Pricescale") [
      set priceScenario read-from-string (item 1 line)
      set readTest replace-item 3 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup the climate information
    if ((item 0 line) = "Climate") [
      setup-climate-defaults (item 1 line)
      set readTest replace-item 4 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup the price information
    if ((item 0 line) = "Price") [
      setup-price-defaults (item 1 line)
      set readTest replace-item 5 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup information for rainfed crop
    if ((item 0 line) = "Rainfed") [
      setup-rainfed-defaults (item 1 line)
      set readTest replace-item 6 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup information for rainfed crop
    if ((item 0 line) = "Irrigated") [
      setup-irrigation-defaults (item 1 line)
      set readTest replace-item 7 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup information for long term storage characteristics
    if ((item 0 line) = "StorageLT") [
      setup-LTstorage-defaults (item 1 line)
      set readTest replace-item 8 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup information for short term storage characteristics
    if ((item 0 line) = "StorageST") [
      setup-STstorage-defaults (item 1 line)
      set readTest replace-item 9 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup information for taps
    if ((item 0 line) = "Tap") [
      setup-taps-defaults (item 1 line)
      set readTest replace-item 10 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup the labour information
    if ((item 0 line) = "Labour") [
      setup-labour-defaults (item 1 line)
      set readTest replace-item 11 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup the household characteristics
    if ((item 0 line) = "Household") [
      setup-household-defaults (item 1 line)
      set readTest replace-item 12 readTest true
      set syntaxFlag false
    ]
    ;
    ; Setup information for short term storage characteristics
    if ((item 0 line) = "Policy") [
      setup-policy-defaults (item 1 line)
      set readTest replace-item 13 readTest true
      set syntaxFlag false
    ]
    ;
    ; Village configuration information
    if ((item 0 line) = "Village") [
      setup-village (item 1 line)
      set syntaxFlag false
    ]
    ;
    ; Now check if there is anything left in the line.  If there is, then
    ; print it out and quit
    ifelse (syntaxFlag) [
      file-close-all
      user-message (word "Unrecognized configuration information: " line)
    ]
    [
      set logString (word logstring line "\n")
    ]
    ;
    set line file-read-skipComments
  ]
  ;
  ; Nothing left to read, done
  file-close
  go-write-log logString
  print "Configuration Done."
end
;
; Setup elevations using a digital elevations model
;
to setup-DEM-defaults [config]
  print "Setup world using a DEM"
  let configList read-from-string config
  if((length configList) != 3) [ 
    user-message (word "Expecting 'DEM [fname pSize pArea]', found " config) 
    file-close-all
  ]
  setup-elevations-DEM config
end
;
; Setup short term storage defaults
;
to setup-STstorage-defaults [config]
  print "New StorageST Defaults"
  let configList read-from-string config
  if((length configList) != 8) [ 
    user-message (word "Expecting 'StorageST [storeType probFail costBuild costMaint numFields baseYield rainYield maxYield]', found " config) 
    file-close-all
  ]
  set glo_polSTlist configList
end
;
; Setup long term storage defaults
;
to setup-LTstorage-defaults [config]
  print "New StorageLT Defaults"
  let configList read-from-string config
  if((length configList) != 8) [ 
    user-message (word "Expecting 'StorageLT [storeType probFail costBuild costMaint numFields baseYield rainYield maxYield]', found " config) 
    file-close-all
  ]
  set glo_polLTlist configList
end
;
; Setup default information for taps
;
to setup-taps-defaults [config]
  print "New Taps Defaults"
  let configList read-from-string config
  if((length configList) != 6) [ 
    user-message (word "Expecting 'Tap [probFail costBuild costMaint numHlds drinkProd drinkSustCost]', found " config) 
    file-close-all
  ]
  set glo_polTaplist configList
end
;
; Setup list of prices
;
to setup-price-defaults [config]
  print "New Price Defaults"
  let configList read-from-string config
  if((length configList) != 4) [ 
    user-message (word "Expecting 'Price [irrigPriceK rainPriceK irrigPriceR rainPriceR]', found " config) 
    file-close-all
  ]
  set glo_priceList configList
end
;
; Get the next line from the file, skipping forward if it is a comment line, and returning nothing if it is the end of the file.
; The file must be open for this to work.
;
to-report file-read-skipComments
  let rep []
  while [(not file-at-end?) and (empty? rep)] [
    let line file-read-line
    if(length line > 0) [
      if ((first line != ";") and (first line != "#") and (first line != "%")) [
        if (position " " line != false) [
          set rep (list (substring line 0 (position " " line)) (substring line ((position " " line) + 1) (length line)))
        ]
      ]
    ]
  ]
  report rep
end
;
; Climate defaults
;
to setup-climate-defaults [config]
  print "New Climate Defaults"
  let configList read-from-string config
  if((length configList) != 2) [ 
    user-message (word "Expecting 'Climate [kharifRain rabiRain]', found " config) 
    file-close-all
  ]
  set glo_kharifRain (item 0 configList)    ; village level average precipitation during kharif
  set glo_rabiRain (item 1 configList)      ; average village level precipitation during rabi 
end  
;
; Household defaults
;
to setup-household-defaults [config]
  print "New Household Defaults"
  let configList read-from-string config
  if((length configList) != 4) [ 
    user-message (word "Expecting 'Household [memHere memAway numFlds iniWealth]', found " config) 
    file-close-all
  ]
  set glo_memHereInit (item 0 configList)
  set glo_memAwayInit (item 1 configList)
  set glo_numFldsInit (item 2 configList)
  set glo_hou_iniWealth (item 3 configList)
end
;
; Labour market defaults
;
to setup-labour-defaults [config]
  print "New Labour Defaults"
  let configList read-from-string config
  if((length configList) != 5) [ 
    user-message (word "Expecting 'Labour [costSustain wageCropShare wageFar migrateCost remitShare]', found " config) 
    file-close-all
  ]
  set glo_costSustain (item 0 configList)
  set glo_wageCropShare (item 1 configList)
  set glo_wageFar (item 2 configList)
  set glo_migrateCost (item 3 configList)
  set glo_remitShare (item 4 configList)
end
;
; Rainfed crop defaults
;
to setup-rainfed-defaults [config]
  print "New Rainfed Defaults"
  let configList read-from-string config
  if((length configList) != 8) [ 
    user-message (word "Expecting 'Rainfed [waterMinK waterMaxK yieldMaxK labNeededK waterMinR waterMaxR yieldMaxR labNeededR]', found " config) 
    file-close-all
  ]
  set glo_rainList configList
end
;
; Irrigation crop defaults
;
to setup-irrigation-defaults [config]
  print "New Irrigated Defaults"
  let configList read-from-string config
  if((length configList) != 8) [ 
    user-message (word "Expecting 'Irrigation [waterMinK waterMaxK yieldMaxK labNeededK waterMinR waterMaxR yieldMaxR labNeededR]', found " config) 
    file-close-all
  ]
  set glo_irrigList configList
end
;
; Setup policy defaults
;
to setup-policy-defaults [config]
  let configList read-from-string config
  if((length configList) != 2) [ 
    user-message (word "Expecting 'Policy [discount policyBudget]', found " config) 
    file-close-all
  ]
  set discount (item 0 configList)
  set policyBudget (item 1 configList)
end
;
; Setup the preliminary housekeeping stuff.  Default values that will be used throughout.
;
to setup-preliminaries
  set-default-shape households "pentagon"
  set-default-shape ponds "circle"
  set-default-shape people "person"
  set-default-shape taps "triangle"
end
;
; Setup global variables
;
to setup-globals
  set discount 0.2          ; discount rate
  set period 0              ; initialize period counter
  set villageFile "Villages.txt" ; file with information about village location and other village characteristics
  ;
  ; Create two villages that are where people migrate to
  create-towns 1 [
    set city self
    set tow_people (turtle-set nobody)
  ]
  create-towns 1 [
    set marketTown self
    set tow_people (turtle-set nobody)
  ]
  ;
  ; Global policy variable values
  set policyBudget 10000  ; amount of money available for policy options
  set policyTechCost 20   ; cost of improving technology on one field
  set policySCcost 2000       ; cost of increasing social capital
  set weatherScenario [1 1]
  set priceScenario [1 1]
  set policyBudgetAcc 0
end
;
; Create the world.  Set up the locations of roads, rivers, elevations, etc.
;
to setup-world [config]
  ;
  ; Set the size of the world
  let lineList read-from-string config
  if((length lineList) != 6) [ 
    user-message (word "Expecting 'World [xMin xMax yMin yMax pSize pArea]', found " config) 
    file-close-all
  ]
  resize-world (item 0 lineList) (item 1 lineList) (item 2 lineList) (item 3 lineList)
  set-patch-size (item 4 lineList)
  set glo_pat_area (item 5 lineList)
  print (word "World Dimensions:  x:[ " min-pxcor " " max-pxcor " ] y:[ " min-pycor " " max-pycor " ]")
  ;
  ; Do things like set the elevation of the cells, locate a road, etc.
  setup-world-landscape
end
;
; Setup the landscape.  This is where information about the patches can be read in.  Things like 
; elevation, normal precipitation, etc. could be read in from a file and then set for each patch.
; It could also work to set other physical features, such as the parameters of the crop production
; functions, at this level.  These could be generated within the program, conditional on things
; like elevation, or imported from somewhere else that has done these calculations.
;
to setup-world-landscape
  ask patches [
    set pat_elevation abs(pxcor - pycor) + (pxcor + pycor) / 10
    ; set pat_elevation (pxcor + pycor) / 2
    set pcolor green + (-4 + pat_elevation / 25)
    set pat_owned nobody
    set pat_area glo_pat_area
  ]  
end
;
; Setup a single village, based on the passed information
;
to setup-village [config]
  ;
  ; Check to see if all the defaults have been set
  if(((item 0 readTest) = false) and ((item 1 readTest) = false)) [ user-message "World not defined!" file-close-all]
  if((item 2 readTest) = false) [ user-message "Weather scenario not defined!"  file-close-all]
  if((item 3 readTest) = false) [ user-message "Price scenario not defined!"  file-close-all]
  if((item 4 readTest) = false) [ user-message "Seasonal precipitation not defined!"  file-close-all]
  if((item 5 readTest) = false) [ user-message "Local prices not defined!"  file-close-all]
  if((item 6 readTest) = false) [ user-message "Rainfed crop details not defined!"  file-close-all]
  if((item 7 readTest) = false) [ user-message "Irrigated crop details not defined!"  file-close-all]
  if((item 8 readTest) = false) [ user-message "Long term storage details not defined!"  file-close-all]
  if((item 9 readTest) = false) [ user-message "Short term storage details not defined!"  file-close-all]
  if((item 10 readTest) = false) [ user-message "Tap information not defined!"  file-close-all]
  if((item 11 readTest) = false) [ user-message "Labour details not defined!"  file-close-all]
  if((item 12 readTest) = false) [ user-message "Household details not defined!"  file-close-all]
  if((item 13 readTest) = false) [ user-message "Policy information not defined!"  file-close-all]
  ;
  ; Create a village
  let line read-from-string config ; read line and turn into list
  if((length line) != 11) [ 
    user-message (word "Expecting 'Village [name xcor ycor numHlds numTaps tanks ponds scCost scRate techCost techMax]', found " config) 
    file-close-all
  ]
  if((item 3 line) > 0) [
    create-villages 1 [
      ;
      ; set initial values for village variables
      village-setup-defaults self line
    ]
  ]
end
;
; Create a number of pens for variables from each village
;
to setup-village-plots
  let colorNum 3
  set-current-plot "Cooperative Spirit"
  set colorNum 3
  foreach (sort villages) [
    ask ? [
      create-temporary-plot-pen vil_name
      set-plot-pen-color colorNum
      set colorNum colorNum + 5
    ]
  ]
  set-current-plot "Population"
  set colorNum 3
  foreach (sort villages) [
    ask ? [
      create-temporary-plot-pen vil_name
      set-plot-pen-color colorNum
      set colorNum colorNum + 5
    ]    
  ]
  set-current-plot "Stored Water"
  set colorNum 3
  foreach (sort villages) [
    ask ? [
      create-temporary-plot-pen vil_name
      set-plot-pen-color colorNum
      set colorNum colorNum + 5
    ]    
  ]
  set-current-plot "Average Wealth"
  set colorNum 3
  foreach (sort villages) [
    ask ? [
      create-temporary-plot-pen vil_name
      set-plot-pen-color colorNum
      set colorNum colorNum + 5
    ]    
  ]
  set-current-plot "Average Income"
  set colorNum 3
  foreach (sort villages) [
    ask ? [
      create-temporary-plot-pen vil_name
      set-plot-pen-color colorNum
      set colorNum colorNum + 5
    ]    
  ]
  ;
  ; Budget allocations, translated from relative position of sliders
  set-current-plot "Annual Budget Allocations"
  create-temporary-plot-pen "ltStorage"
  set-plot-pen-color 3
  create-temporary-plot-pen "stStorage"
  set-plot-pen-color 8
  create-temporary-plot-pen "repairStorage"
  set-plot-pen-color 13
  create-temporary-plot-pen "irrigTech"
  set-plot-pen-color 18
  create-temporary-plot-pen "drinkingWater"
  set-plot-pen-color 23
  create-temporary-plot-pen "SCbuilding"
  set-plot-pen-color 28
  create-temporary-plot-pen "emergRelief"
  set-plot-pen-color 33
  ;
  ; Amount of carryover budget
  set-current-plot "Accumulated Budget"
  create-temporary-plot-pen "ltStorage"
  set-plot-pen-color 3
  create-temporary-plot-pen "stStorage"
  set-plot-pen-color 8
  create-temporary-plot-pen "repairStorage"
  set-plot-pen-color 13
  create-temporary-plot-pen "irrigTech"
  set-plot-pen-color 18
  create-temporary-plot-pen "drinkingWater"
  set-plot-pen-color 23
  create-temporary-plot-pen "SCbuilding"
  set-plot-pen-color 28
  create-temporary-plot-pen "emergRelief"
  set-plot-pen-color 33
end
;******************************************************************************************************************
;* RUN                                                                                                            *
;******************************************************************************************************************
;
; Make the system go
;
to go
  set period period + 1 ; increment period counter
  go-check-simulation
  go-kharif ; process the monsoon season
  go-store-results
  go-rabi ; process the dry season
  go-store-results
end
;
; Store some results for the model as a whole
;
to go-store-results
  ;
  ; If it is the kharif season, then set these things to zero
  if(season = "Kharif") [
    set sim_totWealth 0
    set sim_income 0
    set sim_profit 0
    set sim_wages 0
    set sim_remit 0
    set sim_subsidy 0
    set sim_sustain 0
    set sim_migrate 0
    set sim_maintain 0
    set sim_population 0
    set sim_households 0
    set sim_WSworking 0
    set sim_WS 0
    set sim_taps 0
    set sim_SC 0
    set sim_stored 0
  ]
  ;
  ; Calculate a bunch of stuff to store
  ask villages [
    set sim_totWealth sim_totWealth + sum ([hou_FCcash] of vil_residents) / 2     ; total wealth (divide by two as double counted)
    set sim_income sim_income + sum ([hou_income] of vil_residents)               ; total period income
    set sim_profit sim_profit + sum ([hou_incProfit] of vil_residents)            ; total period income from field profits
    set sim_wages sim_wages + sum([hou_incWages] of vil_residents)                ; total period income from ag labour wages
    set sim_remit sim_remit + sum([hou_incRemit] of vil_residents)                ; total period income from remittances
    set sim_subsidy sim_subsidy + sum([hou_incSubsidy] of vil_residents)          ; total period income from subsidy
    set sim_sustain sim_sustain + sum([hou_cstSustain] of vil_residents)          ; total period expenses for sustanance
    set sim_migrate sim_migrate + sum([hou_cstMigrate] of vil_residents)          ; total period expenses for migration
    set sim_maintain sum([hou_cstMaint] of vil_residents)                         ; total period expenses for storage maintenance
    set sim_population sim_population + count village-get-localMembers self
    set sim_households sim_households + count (vil_residents with [count (hou_members with [peo_inVillage = self]) > 0])
    set sim_SC sim_SC + vil_socCapital / (2 * count villages)
    set sim_stored sim_stored + sum([sto_stored] of vil_storeSet)
  ]
  set sim_WSworking sum ([count vil_storeSet with [sto_working]] of villages)  
  set sim_WS sum ([count vil_storeSet] of villages)
  set sim_taps sum ([count vil_taps] of villages)
  ;
  print "Storing Results."
end
;
; Check to see if this is a simulation, and if it is where we are in the simulation
;
to go-check-simulation
  if(runningSimulation) [
    ;
    ; Check the period and take action if necessary
    ifelse (period >= 10) [
      ;
      ; Set the policy controls
      set ltStorage simLtStorage
      set stStorage simStStorage
      set repairStorage simRepairStorage
      set irrigTech simIrrigTech
      set drinkingWater simDrinkingWater
      set SCbuilding simSCbuilding
      set emergRelief simEmergRelief
      ;
      ; Turn on the policy situation
      set policyBudgetActive true
    ]
    [
      ;
      ; Turn off the policy situation
      set policyBudgetActive false
    ]
  ]
end
;
; Go until period is equal to 10
;
to GoTo10
  while [period < 10] [
    go
  ]
end
;
; Go until period is equal to 20
;
to GoTo20
  while [period < 20] [
    go
  ]
end
;
; Run the perl script that processes the log file into a set of CSV files, for analysis in 
; EXCEL or some other program.
;
; This relies on the 'shell' extension.  This is an external extension, not part of the NetLogo 
; package.
;
to process-log
end
;
; Rainy season activities.  Calculate household crop yield, fill tanks and ponds, etc.
;
to go-kharif
  ;
  ; Set the season 
  ;
  set season "Kharif"
  go-init-season "Kharif"
  ;
  ; At the beginning of the season, farmer chooses the crop to grow
  ;
  print (word period "K: go-crop-choose")
  go-crop-choose
  ;
  ; Allocate the village labour
  ;
  print (word period "K: go-labour-market ")
  go-labour-market 
  ;
  ; First thing that we deal with here is to make it rain.  Precipitation falls,
  ; is collected into the storage, and allocated to the fields.
  ;
  print (word period "K: go-precip kharif")
  go-precip
  print (word period "K: go-update-plots")
  go-update-plots
  go-write-agentInfo "Kharif After Precipitation"
  ;
  ; Grow the crops 
  ;
  print (word period "K: go-grow-crops")
  go-grow-crops
  ;
  ; Deal with all other income generating activities
  ;
  print (word period "K: go-allIncome")
  go-allIncome
  go-write-agentInfo "Kharif After Income"
  ;
  ; Update the plots
  ;
  print (word period "K: go-update-plots")
  go-update-plots
  tick
end
;
; Dry season activities
;
to go-rabi
  ;
  ; Set the season
  ;
  set season "Rabi"
  go-init-season "Rabi"
  ;
  ; Beginning of the Rabi season, farmer chooses the crop to grow
  ;
  print (word period "P: go-crop-choose")
  go-crop-choose
  ;
  ; Allocate the village labour
  ;
  print (word period "P: go-labour-market")
  go-labour-market
  ;
  ; Now do the rain for the rabi season
  ;
  print (word period "P: go-precip rabi")
  go-precip
  go-write-agentInfo "Rabi After Precipitation"
  print (word period "P: go-update-plots")
  go-update-plots
  ;
  ; Grow the crops
  ;
  print (word period "P: go-grow-crops")
  go-grow-crops
  ;
  ; Deal with all other income generating activities
  ;
  print (word period "P: go-allIncome")
  go-allIncome
  go-write-agentInfo "Rabi After Income"
  ;
  ; Sort out the issues with storage construction, maintenance, etc.
  ;
  print (word period "P: go-storage-update")
  go-storage-update
  ;
  ; Deal with the policy options
  ;
  print (word period "P: go-policy")
  go-policy
  go-write-agentInfo "Rabi After Policy"
  ;
  ; Update the plots
  ;
  print (word period "P: go-update-plots")
  go-update-plots
  tick
end
;
; Set the season for the villages
;
to go-init-season [setSeason]
  ask villages [
    village-init-season self setSeason
  ]
end
;
; Deposit water on the patches.  Should probably spread according to elevation, but for now just
; dump the same rain everywhere.  After the precipitation put in the patches, also put it into
; the water available in the fields.  Then fill the storage and distribute the water from storage
; to the fields.
;
to go-precip
  ;
  ; Itterate by village, as have village specific parameters
  ask villages [
    ;
    ; get all owned patches in this village
    village-precipitation self 
  ]
  ;
  ; Collect the water into the storage, and then allocate it to the fields
  go-storage-fill
end
;
; Fill the storage, based on the rainfall in the catchment areas.  Since rain falls on everyone,
; not by village, just do this across the villages.
;
to go-storage-fill
  ;
  ; First, fill up the storage
  ask storage [
    storage-fill self
  ]
end
;
; Distribute the water from the storage to the fields in each village.  We do this in two steps, where
; in the first step, half the water in the storage is distributed.  In the second step, the remainder is
; distributed.  This is so that fields that are connected to multiple storage get some water from each.
;
to go-storage-distribute
  ;
  ; Add the rain from the patches to that availabe to the fields
  ask fields [
    field-water-receive self ([pat_rain] of patch-here)
  ]
  ;
  ; Now get the storage to push water onto the fields
  ask storage [
    storage-share-water self 0.5
  ]
  ask storage [
    storage-share-water self 1.0
  ]
end
;
; Grow the crops.  Could itterage over the villages and then over the households and then over
; the fields to do this.  However, no reason not to just do it over all the fields.  The sun
; shines on all the fields at the same time.
;
to go-grow-crops
  ;
  ; First distribute the water to the fields
  go-storage-distribute
  ;
  ; Then get the crops grown on the fields
  ask fields [
    field-grow-crop self
  ]
end
;
; Do all the income generating activities for the household, and move the income into the cash savings
; account.
;
to go-allIncome
  ask households [
    household-income-costs self
    set hou_FCcash hou_FCcash + hou_income
    if(hou_FCcash < 0) [
      ;
      ; Cash less than zero, try to sell a parcel of land
      household-sell-field self
    ]
  ]
  ;
  ; Do village level stuff
  ask villages [
    village-update-socialCapital self vil_socCapSubsidy
    set vil_socCapSubsidy 0 ; zero it, need to apply money again
  ]
end
;
; Choose the crop for each field.  The simple approach is to set those that are connected to
; irrigation as irrigated, and without it as rainfed.  Could make this more sophisticated,
; such as based on the water that is in storage, and/or the amount of money or the education
; that the farmer or family has.
;
to go-crop-choose
  ask villages [
    ask vil_residents [
      ask hou_NCland [
        field-choose-crop self
      ]
    ]
  ]
end
;
; Solve the labour market for all the villages.  Do this in two steps.  First, check to see 
; if it makes sense to migrate, and migrate if it does.  Then allocate remaining labour
; among fields.
;
to go-labour-market
  ;
  ; Is it a good idea to migrate away?
  ask households [
    household-migrate-away self
  ]
  ;
  ; For those still here, figure out where to work.
  ask villages [
    village-labour-market self
  ]
end
;
; Update everything to do with the storage.  This includes maintenance, construction, etc.
;
to go-storage-update
  ask storage [
    storage-maintenance self
  ]
end
;
; Go and do the policy options
;
to go-policy
  ifelse (policyBudgetActive = true) [
    set policyString "*\n* Policy results:\n*\n"
    go-policy-emergencyPayment
    go-policy-irrigationTechnology
    go-policy-socialCapital
    go-policy-addLTStorage 
    go-policy-addSTStorage
    go-policy-repairStorage
    go-policy-drinkingWater
    ;
    ; Add information to accumulated budget not spent
    ifelse (policy-budget 1 > 0) [
      set policyBudgetAcc policyBudgetAcc + policyBudget * (1 - policyBudgetSpendShare)
    ]
    [
      set policyBudgetAcc policyBudgetAcc + policyBudget
    ]
    ;
    ; Send policy information to log file
    go-write-log policyString
  ]
  [
    set policyBudgetAcc policyBudgetAcc
  ]
end
;
; Calculate the policy budget share, given a budget amount.  If the total of all budgets is
; zero, return zero.
;
to-report policy-budget [budget]
  let ret 0
  let denom ltStorage + stStorage + irrigTech + SCbuilding + emergRelief + repairStorage + drinkingWater
  if (denom > 0) [
    set ret policyBudget * policyBudgetSpendShare * (budget / denom)
  ]
  report ret
end
;
;
; Implement emergency cash payment policy.  Note that all policies are relative, based on 
; a total budget.  How the cash is allocated depends on whether it is random, or directed
; at those with the lowest cash.  Work from a budget that carries forward, if there is any left over.
;
to go-policy-emergencyPayment
  ;
  ; base size of emergency payment on subsistence cost
  let addBudget (policy-budget emergRelief)
  set glo_budgetRelief glo_budgetRelief + addBudget
  if (addBudget > 0) [ set policyString (word policyString "\n*** Emergency relief: ***\n") ]
  ;
  ; Build agentset of people to get a payment, either sorted by cash or not
  ifelse (emergRelief_rnd = true) [
    ;
    ; Pay a randomly chosen set of households
    ask households [
      let memLocal (household-get-localMembers self)
      if(count memLocal > 0) [
        let costSustain  ([vil_costSustain] of ([hou_ourVillage] of self))
        if (glo_budgetRelief >= (costSustain * count memLocal)) [
          let payment (costSustain * count memLocal)
          set hou_incSubsidy payment
          set glo_budgetRelief glo_budgetRelief - payment
          set policyString (word policyString "\n" self ": " payment)
        ]
      ]
    ]
  ]
  [
    ;
    ; Pay based on wealth of households
    foreach (sort-on [hou_FCcash] households) [
      ask ? [
        let memLocal (household-get-localMembers self)
        if(count memLocal > 0) [
          let costSustain  ([vil_costSustain] of ([hou_ourVillage] of self))
          if (glo_budgetRelief >= (costSustain * count memLocal)) [
            let payment (costSustain * count memLocal)
            set hou_incSubsidy payment
            set glo_budgetRelief glo_budgetRelief - payment
            set policyString (word policyString "\n" self ": " payment)
          ]
        ]
      ]
    ]
  ]
  ;
  ; Could accumulate leftover budget for future use, if there is any left over
end
;
; Irrigation technology improvement policy.  Apply technology to a selection of fields, based on the
; amount of budget.
;
to go-policy-irrigationTechnology
  ;
  ; Need to have a technology cost per field, to figure out how many fields new tech can be applied to.
  let techRate 0.5
  ;
  ; Figure out how many fields can get a technological investment
  let addBudget (policy-budget irrigTech)
  set glo_budgetTech glo_budgetTech + addBudget
  if (addBudget > 0) [ set policyString (word policyString "\n*** Irrigation Technology: ***\n") ]
  ;
  ; Apply a technology boost to fields, so long as there is money to do so or there are fields where 
  ; the technology can be applied.  Carry forward any unspent budget
  ifelse (irrigTech_rnd) [
    ask fields [
      if(glo_budgetTech >= fie_techCost) [
        set fie_tech fie_tech + (fie_techMax - fie_tech) * techRate
        set glo_budgetTech glo_budgetTech - fie_techCost
        set policyString (word policyString "\nTEC: " self ": " fie_tech ", " fie_techCost)
      ]
    ]
  ]
  [
    foreach (sort-on [fie_tech] fields) [
      ask ? [
        if(glo_budgetTech >= fie_techCost) [
          set fie_tech fie_tech + (fie_techMax - fie_tech) * techRate
          set glo_budgetTech glo_budgetTech - fie_techCost
          set policyString (word policyString "\nTEC: " self ": " fie_tech ", " fie_techCost)
        ]
      ]
    ]
  ]
end
;
; Policy to increase the amount of social capital.  For simplicity, the policy raises the social capital in the 
; target villages to its maximum, when the policy is applied.  The number of villages where the social capital
; investment takes place depends on the amount of money applied to this policy and the cost of doing so.
;
; The policy can be applied to a random sample of villages, or to those that have the lowest social capital.
;
; Could tie this to the same villages for multiple periods.  Either that, or make it very costly, so that only
; a relatively small number of villages get this investment.
;
to go-policy-socialCapital
  ;
  ; Figure out how many villages get a boost to their social capital
  let addBudget (policy-budget SCbuilding)
  set glo_budgetSC glo_budgetSC + addBudget
  if (addBudget > 0) [ set policyString (word policyString "\n*** Social Capital Enhancement: ***\n") ]
  ;
  ; Build a list of villages where the social capital level will be increased.  Could have a counter here so 
  ; that investments in social capital stay at the same place until some number of periods have passed.  
  ; Would need to keep the list of which villages are receiving the boost so that we know who it is.
  ifelse (SCbuilding_rnd) [
    ask villages [
      if(village-population self > 0) [
        if(glo_budgetSC > vil_polSCcost) [
          set vil_SOCcapital vil_polSCstep
          set glo_budgetSC glo_budgetSC - vil_polSCcost
          set policyString (word policyString "\nSC: " self ": " vil_SOCcapital ", " vil_polSCcost)
        ]
      ]
    ]
  ]   
  [
    foreach (sort-on [vil_SOCcapital] villages) [
      ask ? [
        if(village-population self > 0) [
          if(glo_budgetSC > vil_polSCcost) [
            set vil_SOCcapital vil_polSCstep
            set glo_budgetSC glo_budgetSC - vil_polSCcost
            set policyString (word policyString "\nSC: " self ": " vil_SOCcapital ", " vil_polSCcost)
          ]
        ]
      ]
    ]
  ]   
end
;
; Add more storage.  Are going to do it with two types of storage, long term (tanks) and short term (ponds).
; will just use the information provided in the lists tankInfo and pondInfo.
;
; storeInfo - [number storeType probFail costBuild costMaint numFields capacity catchSize]  
;
to go-policy-addLTStorage 
  ;
  ; Figure out how many fillages get an additional storage built
  let addBudget (policy-budget ltStorage)
  set glo_budgetLTsto glo_budgetLTsto + addBudget
  if (addBudget > 0) [ set policyString (word policyString "\n*** Build Long Term Storage: ***\n") ]
  ;
  ; Come up with a list of villages to receive new long term storage.  Can either select at random, or choose 
  ; those villages with the least number of storage technologies in place.
  ;
  ifelse (ltStorage_rnd) [
    ask villages [
      if((village-population self > 0) and (village-get-water-demand self > 0)) [
        let costBuild (item 2 vil_polLTlist) / vil_SOCcapital
        if (glo_budgetLTsto > costBuild) [
          village-setup-storage self (list (sentence 1 vil_polLTlist))
          set glo_budgetLTsto glo_budgetLTsto - costBuild
          set policyString (word policyString "\nLTS: " self ": " count vil_storeSet)
        ]
      ]
    ]
  ]
  [
    foreach (sort-on [count vil_storeSet with [sto_storeType = (item 0 ([vil_polLTlist] of sto_theVillage))]] villages) [
      ask ? [
        if((village-population self > 0) and (village-get-water-demand self > 0)) [
          let costBuild (item 2 vil_polLTlist) / vil_SOCcapital
          if (glo_budgetLTsto > costBuild) [
            village-setup-storage self (list (sentence 1 vil_polLTlist))
            set glo_budgetLTsto glo_budgetLTsto - costBuild
            set policyString (word policyString "\nLTS: " self ": " count vil_storeSet)
          ]
        ]
      ]
    ]
  ]
end
;
; Add more storage.  Are going to do it with two types of storage, long term (tanks) and short term (ponds).
; will just use the information provided in the lists tankInfo and pondInfo.
;
; storeInfo - [number storeType probFail costBuild costMaint numFields capacity catchSize]  
;
to go-policy-addSTStorage 
  ;
  ; Figure out how many fillages get an additional storage built
  let addBudget (policy-budget stStorage)
  set glo_budgetSTsto glo_budgetSTsto + addBudget
  if (addBudget > 0) [ set policyString (word policyString "\n*** Build Short Term Storage: ***\n") ]
  ;
  ; Come up with a list of villages to receive new long term storage.  Can either select at random, or choose 
  ; those villages with the least number of storage technologies in place.
  ;
  ifelse (stStorage_rnd) [
    ask villages [
      if(village-population self > 0) [
        let costBuild (item 2 vil_polSTlist) / vil_SOCcapital
        if (glo_budgetSTsto > costBuild) [
          village-setup-storage self (list (sentence 1 vil_polSTlist))
          set glo_budgetSTsto glo_budgetSTsto - costBuild
          set policyString (word policyString "\nSTS: " self ": " count vil_storeSet)
        ]
      ]
    ]
  ]
  [
    foreach (sort-on [count vil_storeSet with [sto_storeType = (item 0 ([vil_polSTlist] of sto_theVillage))]] villages) [
      ask ? [
        if(village-population self > 0) [
          let costBuild (item 2 vil_polSTlist) / vil_SOCcapital
          if (glo_budgetSTsto > costBuild) [
            village-setup-storage self (list (sentence 1 vil_polSTlist))
            set glo_budgetSTsto glo_budgetSTsto - costBuild
            set policyString (word policyString "\nSTS: " self ": " count vil_storeSet)
          ]
        ]
      ]
    ]
  ]
end
;
; Spend money repairing the storage.  Repair the storage by applying money until there is none left, or there is no storage
; left that needs to be repaired.
;
to go-policy-repairStorage
  ;
  ; Get the budget that is allocated to repairing storage
  let addBudget (policy-budget repairStorage)
  set glo_budgetRepair glo_budgetRepair + addBudget
  if (addBudget > 0) [ set policyString (word policyString "\n*** Repair Failed Storage: ***\n") ]
  ;
  ; Get all the storage that needs to be repaired
  let stFailed storage with [sto_working = false]
  ;
  ; Fix storage until have no money or no more storage to fix
  ask stFailed [
    if (village-population sto_theVillage > 0) [
      let costRepair (sto_costBuild / 2) / [vil_SOCcapital] of sto_theVillage
      if (glo_budgetRepair >= costRepair) [
        set policyString (word policyString "\nFIX: " sto_theVillage ": " self)
        set sto_working true
        set sto_repaired true
        set sto_repairCost costRepair
        set glo_budgetRepair glo_budgetRepair - costRepair
        set color blue
      ]
    ]
  ]
end
;
; Add more drinking water.  Can just randomly assign new drinking water, or assign new drinking water in the order 
; villages with the largest number of members that don't have access to drinking water.
;
to go-policy-drinkingWater
  ;
  ; get the budget that is allocated to expanding drinking water access
  let addBudget (policy-budget drinkingWater)
  set glo_budgetDrink glo_budgetDrink + addBudget
  if (addBudget > 0) [ set policyString (word policyString "\n*** Repair Failed Storage: ***\n") ]
  ;
  ; Get the set of villages to add drinking water.  Either choose randomly, or order by the number of households
  ; in the village that do not have access to drinking water.
  ifelse (drinkingWater_rnd) [
    ask villages [
      let tapCst (item 1 vil_polTaplist)
      if(village-population self > 0) [
        if (glo_budgetDrink >= tapCst) [
          village-setup-taps self 1
          set glo_budgetDrink glo_budgetDrink - tapCst
          set policyString (word policyString "\nTAP: " self ": " count vil_taps)
        ]
      ]
    ]
  ]
  [
    foreach (sort-on [count village-no-tap self] villages) [
      ask ? [
        let tapCst (item 1 vil_polTaplist)
        if(village-population self > 0) [
          if (glo_budgetDrink >= tapCst) [
            village-setup-taps self 1
            set glo_budgetDrink glo_budgetDrink - tapCst
            set policyString (word policyString "\nTAP: " self ": " count vil_taps)
          ]
        ]
      ]
    ]
  ]
end
;
; Update the plots of village variables.  These are the things that are created initially by the code,
; not by the initial setup of the graphs.
;
to go-update-plots
  set-current-plot "Cooperative Spirit"
  ask villages [
    set-current-plot-pen vil_name
    plot vil_socCapital
  ]
  set-current-plot "Population"
  ask villages [
    set-current-plot-pen vil_name
    let pop 0
    ask vil_residents [ set pop pop + count (household-get-localMembers self) ]
    plot pop
  ]
  set-current-plot "Stored Water"
  ask villages [
    set-current-plot-pen vil_name
    let stored 0
    ask vil_storeSet [ set stored stored + sto_stored ]
    plot stored
  ]
  set-current-plot "Average Wealth"
  ask villages [
    set-current-plot-pen vil_name
    let wealth 0
    ask vil_residents [set wealth wealth + hou_FCcash ]
    plot wealth / count vil_residents
  ]
  set-current-plot "Average Income"
  ask villages [
    set-current-plot-pen vil_name
    let income 0
    ask vil_residents [set income income + hou_income ]
    plot income / count vil_residents
  ]
  set-current-plot "Annual Budget Allocations"
  let policyBudgetDummy 0
  if(policyBudgetActive) [set policyBudgetDummy 1]
  set-current-plot-pen "ltStorage"
  plot policy-budget ltStorage * policyBudgetDummy
  set-current-plot-pen "stStorage"
  plot policy-budget stStorage * policyBudgetDummy
  set-current-plot-pen "repairStorage"
  plot policy-budget repairStorage * policyBudgetDummy
  set-current-plot-pen "irrigTech"
  plot policy-budget irrigTech * policyBudgetDummy
  set-current-plot-pen "drinkingWater"
  plot policy-budget drinkingWater * policyBudgetDummy
  set-current-plot-pen "SCbuilding"
  plot policy-budget SCbuilding * policyBudgetDummy
  set-current-plot-pen "emergRelief"
  plot policy-budget emergRelief * policyBudgetDummy
;  glo_budgetTech    ; technology budget carryover
;  glo_budgetRelief  ; relief budget carryover
;  glo_budgetLTsto   ; long term storage budget carryover
;  glo_budgetSTsto   ; sthort term storage budget carryover
;  glo_budgetSC      ; social capital budget carryover
;  glo_budgetRepair  ; storage repair budget carryover
;  glo_budgetDrink   ; budget for installing new drinking water taps
  set-current-plot "Accumulated Budget"
  set-current-plot-pen "ltStorage"
  plot glo_budgetLTsto
  set-current-plot-pen "stStorage"
  plot glo_budgetSTsto
  set-current-plot-pen "repairStorage"
  plot glo_budgetRepair
  set-current-plot-pen "irrigTech"
  plot glo_budgetTech
  set-current-plot-pen "drinkingWater"
  plot glo_budgetDrink
  set-current-plot-pen "SCbuilding"
  plot glo_budgetSC
  set-current-plot-pen "emergRelief"
  plot glo_budgetRelief
end
;
; Report a sorted list with the names of the villages
;
to-report report-village-names
  let rep []
  foreach (sort villages) [
    set rep (sentence rep vil_name)
  ]
  ; show rep
  report rep
end
;
; Launch an inspect for a passed village name, if it exists
;
to go-inspect-village
  let inspVil villages with [vil_name = inspectName]
  if (inspVil != nobody) [
    inspect one-of inspVil
  ]
end
;
; Reset the log file
;
to reset-log
  if (logFile != "") [
    if (file-exists? logFile) [
      file-delete logFile
    ]
  ]
end
;
; Write output to a file.  Open, append and close file.
;
to go-write-agentInfo [header]
  let outString "********************************************************************************"
  set outString (word outString "\n* Period =" period ": " header)
  set outString (word outString "\n*\n" village-get-toString nobody)
  foreach sort villages [
    if (outString != "") [ set outString (word outString "\n") ]
    set outString (word outString (village-get-toString ?)) 
  ]
  set outString (word outString "\n")
  go-write-log outString
end
;
; Write a string to the log file, or to the screen if there is no log file
;
to go-write-log [str]
  if (recordLog) [
    ifelse (logFile = "") [print str ]
    [
      file-open logFile
      file-print str
      file-close
    ]
  ]
end  
@#$#@#$#@
GRAPHICS-WINDOW
14
740
927
1500
-1
-1
3.0
1
10
1
1
1
0
0
0
1
0
300
0
242
0
0
1
ticks
30.0

BUTTON
235
10
299
43
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
309
10
372
43
Go
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1028
18
1295
147
Stored Water
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS

PLOT
749
155
1019
290
Average Wealth
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS

PLOT
1027
155
1297
293
Population
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS

SLIDER
13
79
46
229
ltStorage
ltStorage
0
100
40
1
1
NIL
VERTICAL

SLIDER
14
237
47
387
stStorage
stStorage
0
100
0
1
1
NIL
VERTICAL

SLIDER
200
397
233
547
SCbuilding
SCbuilding
0
100
12
1
1
NIL
VERTICAL

SLIDER
198
79
231
229
irrigTech
irrigTech
0
100
0
1
1
NIL
VERTICAL

SLIDER
384
399
417
549
emergRelief
emergRelief
0
100
2
1
1
NIL
VERTICAL

SWITCH
55
196
172
229
ltStorage_rnd
ltStorage_rnd
0
1
-1000

SWITCH
56
354
171
387
stStorage_rnd
stStorage_rnd
1
1
-1000

SWITCH
240
196
356
229
irrigTech_rnd
irrigTech_rnd
1
1
-1000

SWITCH
242
514
332
547
scBuilding_rnd
scBuilding_rnd
1
1
-1000

SWITCH
425
516
541
549
emergRelief_rnd
emergRelief_rnd
1
1
-1000

SLIDER
199
238
232
388
drinkingWater
drinkingWater
0
100
32
1
1
NIL
VERTICAL

SLIDER
14
396
47
546
repairStorage
repairStorage
0
100
14
1
1
NIL
VERTICAL

SWITCH
241
355
356
388
drinkingWater_rnd
drinkingWater_rnd
1
1
-1000

PLOT
1028
295
1299
423
Cooperative Spirit
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS

MONITOR
56
127
173
172
NIL
glo_budgetLTsto
17
1
11

MONITOR
56
287
173
332
NIL
glo_budgetSTsto
17
1
11

MONITOR
241
128
357
173
NIL
glo_budgetTech
17
1
11

MONITOR
241
287
357
332
NIL
glo_budgetDrink
17
1
11

MONITOR
243
447
357
492
NIL
glo_budgetSC
17
1
11

MONITOR
428
448
541
493
NIL
glo_budgetRelief
17
1
11

MONITOR
56
447
171
492
NIL
glo_budgetRepair
17
1
11

MONITOR
747
443
907
488
NIL
policyBudget
17
1
11

PLOT
750
17
1018
150
Weather and Price
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"Wea" 1.0 0 -16777216 true "" "plot (item (period mod length weatherScenario) weatherScenario)"
"Pri" 1.0 0 -7500403 true "" "plot (item (period mod length priceScenario) priceScenario)"

MONITOR
1008
513
1682
558
Village Names
sort [vil_name] of villages
17
1
11

BUTTON
915
517
998
550
Inspect
go-inspect-village
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
747
500
905
560
inspectName
Vil 2
1
0
String

PLOT
749
295
1018
432
Average Income
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS

PLOT
384
80
738
230
Annual Budget Allocations
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS

PLOT
384
239
739
392
Accumulated Budget
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS

INPUTBOX
18
10
227
70
configFile
WorldDEM_SL2.txt
1
0
String

MONITOR
241
239
357
284
NIL
policy-budget drinkingWater
17
1
11

MONITOR
55
79
173
124
NIL
policy-budget ltStorage
17
1
11

MONITOR
240
80
357
125
NIL
policy-budget irrigTech
17
1
11

MONITOR
56
239
173
284
NIL
policy-budget stStorage
17
1
11

MONITOR
56
398
171
443
NIL
policy-budget repairStorage
17
1
11

MONITOR
242
397
357
442
NIL
policy-budget SCbuilding
17
1
11

MONITOR
427
400
541
445
NIL
policy-budget emergRelief
17
1
11

SWITCH
564
417
725
450
policyBudgetActive
policyBudgetActive
0
1
-1000

MONITOR
914
443
1074
488
NIL
policyBudgetAcc
17
1
11

SLIDER
564
455
725
488
policyBudgetSpendShare
policyBudgetSpendShare
0
1
1
0.01
1
NIL
HORIZONTAL

INPUTBOX
383
10
571
70
logFile
SL_ABM_logfile.log
1
0
String

BUTTON
575
11
656
44
NIL
reset-log
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
235
45
299
78
NIL
GoTo10
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
309
45
372
78
NIL
GoTo20
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
661
11
742
44
NIL
process-log
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
576
46
742
79
recordLog
recordLog
1
1
-1000

SLIDER
12
567
45
717
precipScale1
precipScale1
0
2
1.8
0.05
1
NIL
VERTICAL

SLIDER
57
568
90
718
precipScale2
precipScale2
0
2
1.8
0.05
1
NIL
VERTICAL

SLIDER
101
569
134
719
precipScale3
precipScale3
0
2
1
0.05
1
NIL
VERTICAL

SLIDER
145
570
178
720
precipScale4
precipScale4
0
2
1
0.05
1
NIL
VERTICAL

SLIDER
186
569
219
719
precipScale5
precipScale5
0
2
1
0.05
1
NIL
VERTICAL

SLIDER
227
570
260
720
precipScale6
precipScale6
0
2
1
0.05
1
NIL
VERTICAL

SLIDER
268
571
301
721
precipScale7
precipScale7
0
2
1
0.05
1
NIL
VERTICAL

SLIDER
309
572
342
722
precipScale8
precipScale8
0
2
1
0.05
1
NIL
VERTICAL

SLIDER
349
571
382
721
precipScale9
precipScale9
0
2
1
0.05
1
NIL
VERTICAL

SLIDER
390
571
423
721
precipScale10
precipScale10
0
2
1
0.05
1
NIL
VERTICAL

SLIDER
430
571
463
721
precipScale11
precipScale11
0
2
1
0.05
1
NIL
VERTICAL

SLIDER
470
572
503
722
precipScale12
precipScale12
0
2
1.8
0.05
1
NIL
VERTICAL

SLIDER
511
573
544
723
precipScale13
precipScale13
0
2
1.6
0.05
1
NIL
VERTICAL

SLIDER
551
574
584
724
precipScale14
precipScale14
0
2
1.6
0.05
1
NIL
VERTICAL

SLIDER
591
573
624
723
precipScale15
precipScale15
0
2
1.6
0.05
1
NIL
VERTICAL

SLIDER
631
573
664
723
precipScale16
precipScale16
0
2
1.2
0.05
1
NIL
VERTICAL

SLIDER
671
573
704
723
precipScale17
precipScale17
0
2
1.6
0.05
1
NIL
VERTICAL

SLIDER
711
573
744
723
precipScale18
precipScale18
0
2
1
0.05
1
NIL
VERTICAL

SLIDER
751
573
784
723
precipScale19
precipScale19
0
2
1
0.05
1
NIL
VERTICAL

SLIDER
791
573
824
723
precipScale20
precipScale20
0
2
1
0.05
1
NIL
VERTICAL

SWITCH
1053
693
1205
726
runningSimulation
runningSimulation
0
1
-1000

SLIDER
840
572
1012
605
simLtStorage
simLtStorage
0
100
40
1
1
NIL
HORIZONTAL

SLIDER
840
606
1012
639
simStStorage
simStStorage
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
840
640
1012
673
simRepairStorage
simRepairStorage
0
100
14
1
1
NIL
HORIZONTAL

SLIDER
840
675
1012
708
simIrrigTech
simIrrigTech
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
1015
572
1187
605
simDrinkingWater
simDrinkingWater
0
100
32
1
1
NIL
HORIZONTAL

SLIDER
1015
606
1187
639
simSCbuilding
simSCbuilding
0
100
12
1
1
NIL
HORIZONTAL

SLIDER
1013
639
1185
672
simEmergRelief
simEmergRelief
0
100
2
1
1
NIL
HORIZONTAL

@#$#@#$#@
# Netlogo Village Economy Model

This model represents a simple village economy.  The model entities are the fields, taps, people, households, water storage, villages and cities.  Fields and people belong to households.  Fields can be connected to water storage that supplies irrigation.  Households can be connected to taps that supply potable water.  Villages contain households, taps and water storage.

The model was used as part of a research project dissemination meeting.

## HOW IT WORKS

### Entities
**Fields:** Grow agricultural crops as a function of water and labour applied.
**Taps:** Provide potable water to attached households.
**People:** Are available to work on fields in the village or can migrate to a city and pay remittances.
**Households:** Contain people as members.  Own fields.  Pay subsistence costs for members living in the village, pay maintenance cost share for fields connected to water storage.  Allocate labour to own fields and through labour market to other fields.  Decide if a member is to move away.  Buy and sell fields.
**Water Storage:** Store water from a constant flow spring and a share of rainfall.  Make water available to fields at start of growing season.
**Villages:** Contain village households, storage and taps.  Track level of social capital.  High social capital makes it easy to secure contributions from village members for construction, maintenance and repair of water storage.

### Time Sequence

Time is divided into the kharif (rainy) season, the rabi (dry) season, and the policy period.  

In both the kharif and rabi seasons, the same sequence is followed.  First, the crop is set for each farmed field, based on season and access to irrigation.  The labour market is then used to allocate labour to the fields, where labour demand is based on assuming that there will be sufficient water.  Precipitation then comes, water storage systems are filled, and water is made available to the fields which are connected to storage.  The crops are then grown, revenue is calculated, and seasonal household expenditures are paid.  At the end of the season, households also decide if a member should migrate.

Policies are evaluated after the rabi season is concluded.  Depending on the policy choices in place, at this time any new storage and new taps are built, failed storage is repaired, field level technology enhanced, social capital is increased, and direct cash payments made to households.  All of these activities can be based on greatest need or distributed among the relevant entity at random.  Greatest need was used for the simulations.

### Initialization

The model reads information from a configuration file.  The name of the configuration file is entered in an input box in the top left of the interface pane.  The information contained in the configuration file defines most of the variables relevant to the model.  This format was chosen so that it would be easy to adjust variables and a host of initial conditions.  One option in this configuration file is to specify a Digital Elevation Model (DEM) that can be loaded to create the landscape on which the model runs.  

Consult this file for the detail of the fields that are used and the information required.  

## HOW TO USE IT

**Setup** loads information from the configuration model and sets up the virtual world.
**Go** proceeds through one year.
**Go to 10** and **Go to 20** run the model until 10 and 20 years have passed.
**logFile** contains the name of the log file to which detailed output is written.  The log can be reset, and logging can be turned on and off.
The sliders **ltStorage**, **stStorage**, **repairStorage**, **irrigTech**, **drinkingWater**, **scBuilding**, and **emergeRelief** control the share of the policy budget that is applied to each of these activities.  The corresponding switches with the subscript **_rnd** control whether the interventions are applied to randomly selected fields, households, or villages, or if they go to those with the greatest need.  Specifically, the activities are building new long term storage, building new short term storage, repairing existing storage that isn't functioning, investing in improved field level water efficiency, installing driking water taps, building social capital, and paying a subsidy directly to households.
**policyBudgetActive** and **policyBudgetSpendShare** control whether policy interventions are active, and if they are what share of the policy budget is applied.  The total policy budget is specified in the configuration file.
**precipScale1** through **precipScale20** control the precipitation scaling factor for each of the years one through twenty.  If the simulation control is set active, then the precipitation for a particular year will be read from the appropriate slider.  The **simLtStorage** through **simEmergRelief** sliders control the levels of the policy variables during the policy period - years 11 to 20 - applied when a simulation is being run.  All these simulation controlers are not used if the simulation switch is off.  In this case, information read from the configuration file and entered in the relevant controlers is used.

The output panels show the averages for each village being modelled.  The landscape is shown in the lower part of the interface.  Differences in patch color reflect the elevation of the patch.

## THINGS TO NOTICE

How policy choices impact on migration rates, social capital, and average income and wealth.

## THINGS TO TRY

For the running model, most of the action is from the policy sliders.  There is also much that can be explored by playing with the configuration file.

## EXTENDING THE MODEL

  * Local migration with return.
  * Remittances diminishing over time.
  * Migration cost function of previous migration.
  * Transportation costs and investment in roads.
  * Input markets.
  * Human capital (skills, eduction).
  * Education as a policy option.
  * Age structured population.
  * Gender structured population.
  * Hydrologic detail.
  * Environmental effects.
  * Flooding risk as well as drought risk.

## NETLOGO FEATURES

The main coding challenges lay in figuring out how to use a configuration file and in organizing the different entities.  Reading the configuration file was quite easy, but a configuration file language had to be chosen that would make it simple to build a file and for NetLogo to process it.  See the configuration file itself for how this was solved.

Organizing the entities was a challenge because NetLogo is not an object oriented programming environment.  Multiple code files were used to approximate the organization of objects, but agent specific local variables could not be cleanly defined in the agent file itself.  This made coding somewhat complicated.  

## CREDITS AND REFERENCES

Code generated by:

Dr. John Janmaat
Department of Economics
I.K. Barber School of Arts and Sciences
The University of British Columbia
Kelowna, British Columbia, Canada
john.janmaat@ubc.ca

Contact Dr. Janmaat for more extensive documentation and research results generated using this model.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="20"/>
    <metric>period</metric>
    <metric>sim_totWealth</metric>
    <metric>sim_income</metric>
    <metric>sim_profit</metric>
    <metric>sim_wages</metric>
    <metric>sim_remit</metric>
    <metric>sim_subsidy</metric>
    <metric>sim_sustain</metric>
    <metric>sim_migrate</metric>
    <metric>sim_maintain</metric>
    <metric>sim_population</metric>
    <metric>sim_households</metric>
    <metric>sim_WSworking</metric>
    <metric>sim_WS</metric>
    <metric>sim_taps</metric>
    <metric>sim_SC</metric>
    <metric>sim_stored</metric>
    <enumeratedValueSet variable="precipScale13">
      <value value="0.4"/>
      <value value="0.8"/>
      <value value="1.2"/>
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="precipScale14">
      <value value="0.4"/>
      <value value="0.8"/>
      <value value="1.2"/>
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="precipScale15">
      <value value="0.4"/>
      <value value="0.8"/>
      <value value="1.2"/>
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="precipScale16">
      <value value="0.4"/>
      <value value="0.8"/>
      <value value="1.2"/>
      <value value="1.6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="precipScale17">
      <value value="0.4"/>
      <value value="0.8"/>
      <value value="1.2"/>
      <value value="1.6"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
